import { fetchOssInitData } from '@/api/doc'
import OSS from 'ali-oss'
let client = null
let baseFileUrl = ''

function noop() {}

const defaultOptoins = {
  // 设置并发上传的分片数量。
  parallel: 10,
  // 设置分片大小。默认值为1 MB，最小值为100 KB。
  partSize: 1024 * 1024,
  headers: {
    // 指定初始化分片上传时是否覆盖同名Object。此处设置为true，表示禁止覆盖同名Object。
    'x-oss-forbid-overwrite': 'true'
  },
  onProgress: noop,
  onSuccess: noop,
  onError: noop
}

async function initOssClient() {
  try {
    const res = await fetchOssInitData()
    if (res.code) return
    const { accessKeyId, securityToken, bucket, accessKeySecret } = res.data
    const config = {
      // 以华东1（杭州）为例，Region填写为oss-cn-hangzhou。
      region: 'oss-cn-shenzhen',
      accessKeyId,
      accessKeySecret,
      stsToken: securityToken,
      bucket
    }
    client = new OSS(config)
    baseFileUrl = `https://${bucket}.${config.region}.aliyuncs.com/`
  } catch (error) {
    console.log(error)
  }
}

export async function multipartUpload(rawFile, options = defaultOptoins) {
  // 合并配置项
  options = { ...defaultOptoins, ...options }
  if (!client) {
    await initOssClient()
  }
  try {
    const strList = rawFile.name.split('.')
    const name = process.env.VUE_APP_UPLOAD_DIR + rawFile.uuid + '.' + strList[strList.length - 1]
    // 分片上传
    const res = await client.multipartUpload(name, rawFile, {
      // 获取分片上传进度、断点和返回值。
      progress: (p, cpt, res) => {
        options.onProgress({ p, cpt, res })
      },
      // 设置并发上传的分片数量。
      parallel: defaultOptoins.parallel,
      // 设置分片大小。默认值为1 MB，最小值为100 KB。
      partSize: defaultOptoins.partSize,
      // 文件类型
      mime: rawFile.type,
      headers: defaultOptoins.headers
    })
    const ossUrl = baseFileUrl + res.name
    options.onSuccess(res, ossUrl)
    return res
  } catch (error) {
    options.onError(error)
  }
}
